---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2019-02-11;12
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20190212&codiceRedaz=19G00017&dataVigenza=20251104
dataGU: 20190212
codiceRedaz: 19G00017
dataVigenza: 20251104
---

# Conversione in legge, con modificazioni, del decreto-legge 14 dicembre 2018, n. 135, recante disposizioni urgenti in materia di sostegno e semplificazione per le imprese e per la pubblica amministrazione. (19G00017)

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

1. Il decreto-legge 14 dicembre 2018, n. 135, recante disposizioni urgenti in materia di sostegno e semplificazione per le imprese e per la pubblica amministrazione, e' convertito in legge con le modificazioni riportate in allegato alla presente legge.

2. Il decreto-legge 29 dicembre 2018, n. 143, e' abrogato. Restano validi gli atti e i provvedimenti adottati e sono fatti salvi gli effetti prodottisi ed i rapporti giuridici sorti sulla base del medesimo decreto-legge 29 dicembre 2018, n. 143.

3. Il decreto-legge 11 gennaio 2019, n. 2, e' abrogato. Restano validi gli atti e i provvedimenti adottati e sono fatti salvi gli effetti prodottisi ed i rapporti giuridici sorti sulla base del medesimo decreto-legge 11 gennaio 2019, n. 2.

4. La presente legge entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale.

